part of '../../moru_payment_gateway.dart';

class PaymentHandler {
  final String baseNewsUrl = Constants.BASE_URL;
  final Dio _dio;

  PaymentHandler({required dio}) : _dio = dio;

  Map<String, dynamic> _checkResponseStatusCode(Response<dynamic> response,) {
    //print(response.data.toString());
    final Map<String, dynamic> gatewayResMap = response.data;

    switch (response.statusCode) {
      //ok code
      case 200:
        return gatewayResMap;

      /* case 400:
        throw BadRequest(errorMessage);

      case 9000:
        throw InsufficientBalance(errorMessage);

      case 9001:
        throw PinUnset(errorMessage);

      case 9002:
        throw InvalidUser(errorMessage);

      case 9004:
        throw InvalidOtp(errorMessage);

      case 9007:
        throw PaymentAlreadyCompleted(errorMessage);

      case 9008:
        throw OTPExpired(errorMessage);

      case 401:
        throw UnauthorizedException('Unauthorized Access');

      case 403:
        throw UnauthorizedException('Unauthorized Access');*/

      default:
        throw DioError(
            requestOptions: response.requestOptions, response: response);
    }
  }

  Future<ValidatedAccessRes?> validateAccess(
      {required CheckoutOptions checkoutOptions}) async {
    try {
      final validateAccessApi =
          Uri.parse("${baseNewsUrl + Constants.VALIDATE_ACCESS_KEY}");
      Map<String, dynamic> requestBody = checkoutOptions.toJson();

      FormData formData = new FormData.fromMap(requestBody);
      final Response response =
          await _dio.post(validateAccessApi.toString(), data: formData);

      final Map<String, dynamic> accessValidatedMap =
          _checkResponseStatusCode(response);

      final ValidatedAccessRes validatedAccessRes =
          ValidatedAccessRes.fromJson(accessValidatedMap);

      return validatedAccessRes;
    } catch (_) {
      _checkResponseStatusCode((_ as DioError).response!);
    }
  }

  Future<ValidatedUserRes?> validateUser(
      {required UserValidate userValidate}) async {
    final Uri userValidatedUrl =
        Uri.parse(baseNewsUrl + "${Constants.VALIDATE_USER}");

    Map<String, dynamic> requestBody = userValidate.toJson();
    FormData formData = new FormData.fromMap(requestBody);
    try {
      final Response response =
          await _dio.post(userValidatedUrl.toString(), data: formData);
      final Map<String, dynamic> userValidatedMap =
          _checkResponseStatusCode(response);

      final ValidatedUserRes validatedUserRes =
          ValidatedUserRes.fromJson(userValidatedMap);

      return validatedUserRes;
    } catch (_) {
      _checkResponseStatusCode((_ as DioError).response!);
    }
  }

  Future<bool> initiatePay({required PayData payData}) async {
    final Uri payUrl = Uri.parse(baseNewsUrl + "${Constants.VALIDATE_OTP}");

    Map<String, dynamic> requestBody = payData.toJson();
    FormData formData = new FormData.fromMap(requestBody);
    try {
      final Response response =
          await _dio.post(payUrl.toString(), data: formData);

      final Map<String, dynamic>? payResponseMap =
          _checkResponseStatusCode(response);

      if (payResponseMap != null) return true;
      return false;
    } catch (_) {
      _checkResponseStatusCode((_ as DioError).response!);
    }
    return false;
  }
}
